@@ -6,8 +6,7 @@ from importlib import import_module
 import click
 
 from ..utils import pretty_info
-from ... import __version__
-from ...binaries import PRISMA_VERSION, ENGINE_VERSION
+from ... import __version__, config
 from ...binaries.platform import binary_platform
 
 
@@ -23,7 +22,7 @@ from ...binaries.platform import binary_platform
 def cli(output_json: bool) -> None:
     """Display Prisma Client Python version information."""
     extras = {
-        'dev': 'tox',
+        'dev': 'nox',
         'docs': 'mkdocs',
     }
     installed: List[str] = []
@@ -36,10 +35,10 @@ def cli(output_json: bool) -> None:
             installed.append(extra)
 
     info = {
-        'prisma': PRISMA_VERSION,
+        'prisma': config.prisma_version,
         'prisma client python': __version__,
         'platform': binary_platform(),
-        'engines': ENGINE_VERSION,
+        'engines': config.engine_version,
         'install path': str(Path(__file__).resolve().parent.parent.parent),
         'installed extras': installed,
     }
